@@ -508,6 +508,16 @@ class RpcDevice:
         }
         await self.call_rpc("Cury.SetAwayMode", params=params)
 
+    async def cury_set_mode(
+        self,
+        id_: int,
+        value: str,
+    ) -> None:
+        """Set mode for Cury."""
+        params: dict[str, Any] = {"id": id_}
+        params["mode"] = None if value == "none" else value
+        await self.call_rpc("Cury.SetMode", params=params)
+
     async def enum_set(self, id_: int, value: str) -> None:
         """Set the value for the enum component."""
         params = {
@@ -565,6 +575,11 @@ class RpcDevice:
         cover_status = await self.cover_get_status(id_)
         self._status[key].update(cover_status)
 
+    async def wall_display_set_screen(self, value: bool) -> None:
+        """Set Wall Display screen on/off."""
+        params = {"on": value}
+        await self.call_rpc("Ui.Screen.Set", params)
+
     async def poll(self) -> None:
         """Poll device for calls that do not receive push updates."""
         calls: list[tuple[str, dict[str, Any] | None]] = [("Shelly.GetStatus", None)]
